summaryrefslogtreecommitdiff
path: root/msm8909/libqservice/IQService.h
diff options
context:
space:
mode:
Diffstat (limited to 'msm8909/libqservice/IQService.h')
-rw-r--r--msm8909/libqservice/IQService.h70
1 files changed, 50 insertions, 20 deletions
diff --git a/msm8909/libqservice/IQService.h b/msm8909/libqservice/IQService.h
index 0f0dc4c1..f9aa7fde 100644
--- a/msm8909/libqservice/IQService.h
+++ b/msm8909/libqservice/IQService.h
@@ -1,6 +1,6 @@
/*
* Copyright (C) 2010 The Android Open Source Project
- * Copyright (C) 2012-2015, The Linux Foundation. All rights reserved.
+ * Copyright (C) 2012-2014, 2016-2017 The Linux Foundation. All rights reserved.
*
* Not a Contribution, Apache license notifications and license are
* retained for attribution purposes only.
@@ -28,6 +28,7 @@
#include <binder/IInterface.h>
#include <binder/IBinder.h>
#include <IQClient.h>
+#include <IQHDMIClient.h>
namespace qService {
@@ -39,25 +40,41 @@ public:
DECLARE_META_INTERFACE(QService);
enum {
COMMAND_LIST_START = android::IBinder::FIRST_CALL_TRANSACTION,
- SECURING, // Hardware securing start/end notification
- UNSECURING, // Hardware unsecuring start/end notification
- CONNECT, // Connect to qservice
- SCREEN_REFRESH, // Refresh screen through SF invalidate
- EXTERNAL_ORIENTATION, // Set external orientation
- BUFFER_MIRRORMODE, // Buffer mirrormode
- CHECK_EXTERNAL_STATUS, // Check status of external display
- GET_DISPLAY_ATTRIBUTES, // Get display attributes
- SET_HSIC_DATA, // Set HSIC on dspp
- GET_DISPLAY_VISIBLE_REGION, // Get the visibleRegion for dpy
- SET_SECONDARY_DISPLAY_STATUS, // Sets secondary display status
- SET_PARTIAL_UPDATE, // Preference on partial update feature
- SET_VIEW_FRAME, // Set view frame of display
- DYNAMIC_DEBUG, // Enable more logging on the fly
- SET_IDLE_TIMEOUT, // Set idle timeout for GPU fallback
+ GET_PANEL_BRIGHTNESS = 2, // Provides ability to set the panel brightness
+ SET_PANEL_BRIGHTNESS = 3, // Provides ability to get the panel brightness
+ CONNECT_HWC_CLIENT = 4, // Connect to qservice
+ SCREEN_REFRESH = 5, // Refresh screen through SF invalidate
+ EXTERNAL_ORIENTATION = 6,// Set external orientation
+ BUFFER_MIRRORMODE = 7, // Buffer mirrormode
+ CHECK_EXTERNAL_STATUS = 8,// Check status of external display
+ GET_DISPLAY_ATTRIBUTES = 9,// Get display attributes
+ SET_HSIC_DATA = 10, // Set HSIC on dspp
+ GET_DISPLAY_VISIBLE_REGION = 11,// Get the visibleRegion for dpy
+ SET_SECONDARY_DISPLAY_STATUS = 12,// Sets secondary display status
+ SET_MAX_PIPES_PER_MIXER = 13,// Set max pipes per mixer for MDPComp
+ SET_VIEW_FRAME = 14, // Set view frame of display
+ DYNAMIC_DEBUG = 15, // Enable more logging on the fly
+ SET_IDLE_TIMEOUT = 16, // Set idle timeout for GPU fallback
+ TOGGLE_BWC = 17, // Toggle BWC On/Off on targets that support
/* Enable/Disable/Set refresh rate dynamically */
- CONFIGURE_DYN_REFRESH_RATE,
- QDCM_SVC_CMDS, // request QDCM services.
- TOGGLE_SCREEN_UPDATE, // Provides ability to disable screen updates
+ CONFIGURE_DYN_REFRESH_RATE = 18,
+ CONTROL_PARTIAL_UPDATE = 19, // Provides ability to enable/disable partial update
+ TOGGLE_SCREEN_UPDATES = 20, // Provides ability to set the panel brightness
+ SET_FRAME_DUMP_CONFIG = 21, // Provides ability to set the frame dump config
+ SET_S3D_MODE = 22, // Set the 3D mode as specified in msm_hdmi_modes.h
+ CONNECT_HDMI_CLIENT = 23, // Connect HDMI CEC HAL Client
+ QDCM_SVC_CMDS = 24, // request QDCM services.
+ SET_ACTIVE_CONFIG = 25, //Set a specified display config
+ GET_ACTIVE_CONFIG = 26, //Get the current config index
+ GET_CONFIG_COUNT = 27, //Get the number of supported display configs
+ GET_DISPLAY_ATTRIBUTES_FOR_CONFIG = 28, //Get attr for specified config
+ SET_DISPLAY_MODE = 29, // Set display mode to command or video mode
+ SET_CAMERA_STATUS = 30, // To notify display when camera is on and off
+ MIN_HDCP_ENCRYPTION_LEVEL_CHANGED = 31,
+ GET_BW_TRANSACTION_STATUS = 32, //Client can query BW transaction status.
+ SET_LAYER_MIXER_RESOLUTION = 33, // Enables client to set layer mixer resolution.
+ SET_COLOR_MODE = 34, // Overrides the QDCM mode on the display
+ GET_HDR_CAPABILITIES = 35, // Get HDR capabilities for legacy HWC interface
COMMAND_LIST_END = 400,
};
@@ -72,6 +89,14 @@ public:
DEBUG_VSYNC,
DEBUG_VD,
DEBUG_PIPE_LIFECYCLE,
+ DEBUG_DRIVER_CONFIG,
+ DEBUG_ROTATOR,
+ DEBUG_QDCM,
+ DEBUG_SCALAR,
+ DEBUG_CLIENT,
+ DEBUG_DISPLAY,
+ DEBUG_MAX_VAL = DEBUG_DISPLAY, // Used to check each bit of the debug command paramater.
+ // Update DEBUG_MAX_VAL when adding new debug tag.
};
enum {
@@ -80,8 +105,13 @@ public:
ENABLE_PARTIAL_UPDATE,
};
- // Register a client that can be notified
+ // Register a HWC client that can be notified
+ // This client is generic and is intended to get
+ // dispatches of all events calling into QService
virtual void connect(const android::sp<qClient::IQClient>& client) = 0;
+ // Register an HDMI client. This client gets notification of HDMI events
+ // such as plug/unplug and CEC messages
+ virtual void connect(const android::sp<qClient::IQHDMIClient>& client) = 0;
// Generic function to dispatch binder commands
// The type of command decides how the data is parceled
virtual android::status_t dispatch(uint32_t command,